@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0404';
+our $VERSION = '0.0500';
 
 use Moo;
 use strictures 2;
@@ -211,6 +211,46 @@ sub _composem {
 }
 
 
+sub compmrnd {
+    my ($self, $n, $m) = @_;
+    return [0] unless $n;
+    my @compositions;
+    my ($p, $j, $np);
+    for(my $mp = $m - 1, $np = $n - 1, $j = 1; $mp > 0; --$np) {
+        $p = $mp / $np;
+        if ($p % 2 == 0) {
+            push @compositions, $j;
+            $mp--;
+            $j = 1;
+        }
+        else {
+            $j++;
+        }
+    }
+    push @compositions, $j + $np;
+    return \@compositions;
+}
+
+
+sub comprnd {
+    my ($self, $n) = @_;
+    return [0] unless $n;
+    my @compositions;
+    my $p = 1;
+    for my $i (1 .. $n - 1) {
+        if ((int rand 2) % 2 == 0) {
+            $p++;
+        }
+        else {
+            push @compositions, $p;
+            $p = 1;
+        }
+    }
+    push @compositions, $p;
+    return \@compositions;
+}
+
+
 sub de_bruijn {
     my ($self, $n) = @_;
     my $sequence = $n ? debruijn([1,0], $n) : 0;
@@ -529,7 +569,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0404
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -658,6 +698,26 @@ Example:
 
   $got = $mcr->compm(4, 2); # [[1,3],[2,2],[3,1]]
 
+=head2 compmrnd
+
+  $composition = $mcr->compmrnd($n);
+
+Generate a random composition of B<n>.
+
+Example:
+
+  $got = $mcr->compmrnd(16, 4); # [6,1,3,6], etc.
+
+=head2 comprnd
+
+  $composition = $mcr->comprnd($n);
+
+Generate a random composition of B<n>.
+
+Example:
+
+  $got = $mcr->comprnd(16); # [1,3,2,1,1,2,1,3,2], etc.
+
 =head2 de_bruijn
 
   $sequence = $mcr->de_bruijn($n);
@@ -666,7 +726,7 @@ Generate the largest de Bruijn sequence of order B<n>.
 
 Example:
 
-  $got = $mcr->de_bruijn(3); # 1 1 1 0 1 0 0 0
+  $got = $mcr->de_bruijn(3); # [1,1,1,0,1,0,0,0]
 
 =head2 euclid
 
